import logging
from pathlib import Path
from configparser import ConfigParser
from systemd.journal import JournalHandler
from .helpers import load_config

# This applies to all logger instances initialized by any module.
logging.basicConfig(
    force=True,
    level=logging.INFO,
    format='%(message)s',
    handlers=[JournalHandler(SYSLOG_IDENTIFIER='inventory-client')]
)

# Get the config file parser.
config = load_config(path='/etc/inventory-client.ini', fatal=True, parser=ConfigParser())

# Enable debug logging if specified in the config.
# This applies to all logger instances initialized by any module.
if config.get('logging', 'debug') == 'true':
    logging.basicConfig(
        force=True,
        level=logging.DEBUG,
        format='%(levelname)s :: %(name)s :: %(message)s',
        handlers=[JournalHandler(SYSLOG_IDENTIFIER='inventory-client')]
    )

# Shared stuff:
api_url = config.get('api', 'url')
api_user = config.get('api', 'user')
api_pass = config.get('api', 'pass')
conf_dir = '/etc/inventory-client.d'
# The modification timestamp of this file is used to keep track of when the data was last sent.
timestamp = Path('/run/inventory-client/timestamp')

# Get rid of unnecessary stuff.
del config
