import sys
import logging
import requests
from time import sleep
from . import api_url, api_user, api_pass, timestamp

log = logging.getLogger(__name__)


def send(api_data: dict) -> None:
    log.info('Sending data')

    pause = 10
    attempts = 10
    for attempt in range(1, attempts + 1):
        if not attempt == 1:
            log.error(f'Retrying in {pause} seconds')
            sleep(pause)
            pause *= 2

        try:
            # Using "json=" instead of "data=" automatically adds
            # the required Content-Type header and encodes the dict.
            r = requests.post(url=api_url, auth=(api_user, api_pass), json=api_data, timeout=10)
            r.raise_for_status()
        except Exception as e:
            try:
                log.error(f'({attempt}/{attempts}) Send failed: {e} | Content: {r.text} | Headers: {r.headers}')
            except NameError:
                log.error(f'({attempt}/{attempts}) Send failed: {e}')
            continue

        # "touch" sets the modification time of the file to the current time.
        timestamp.touch()
        log.info(f'Send successful: {r.status_code} {r.reason}')
        log.debug(f'Content: {r.text} | Headers: {r.headers}')
        break

    else:
        log.critical('Max attempts reached')
        sys.exit(1)
