# Python 3.9 (Debian Bullseye) does not allow writing union types as X | Y.
# Remove __future__ import when Bullseye support is no longer necessary.
from __future__ import annotations
import sys
import logging
from configparser import ConfigParser

log = logging.getLogger(__name__)


def load_config(path: str, fatal: bool, parser: ConfigParser) -> ConfigParser | None:
    try:
        with open(path, 'r') as f:
            parser.read_file(f)

    except IOError as e:
        if fatal:
            log.critical(f'Could not read file: {e}')
            sys.exit(1)
        log.debug(f'Could not read file: {e}')
        return None

    return parser
